@@ -31,8 +31,8 @@ class MainWindow : public QWidget {
         void resumeButtonPressed();
         void settingsButtonPressed();
         void helpButtonPressed();
-        void fileSelected( int row, int column );
-        void cellClicked( int row, int column );
+        void fileSelected();
+        void cellClicked();
         void resort( int column );
         void playerStart();
         void playerStop();
@@ -41,7 +41,7 @@ class MainWindow : public QWidget {
         QString toHHMMSS( unsigned int tenthOfASec );
 
     private:
-        QTableWidget* m_fileList;
+        QTableView* m_fileList;
         QPushButton* m_playbutton;
         QPushButton* m_resumebutton;
         int m_sortByColumn;
